diff --git a/src/openvpn/options.c b/src/openvpn/options.c
index 61fa983..60f4b6f 100644
--- a/src/openvpn/options.c
+++ b/src/openvpn/options.c
@@ -3790,11 +3790,14 @@ options_warning_safe_scan2(const int msglevel,
                            const char *b1_name,
                            const char *b2_name)
 {
     /* we will stop sending 'proto xxx' in OCC in a future version
      * (because it's not useful), and to reduce questions when
      * interoperating, we start not-printing a warning about it today
      */
-    if (strncmp(p1, "proto ", 6) == 0)
+    if (strcmp(p1, "key-method ") == 0
+        || strcmp(p1, "keydir ") == 0
+        || strcmp(p1, "proto ") == 0
+        || strcmp(p1, "tls-auth ") == 0)
     {
         return;
     }
@@ -3790,11 +3790,14 @@ options_warning_safe_scan2(const int msglevel,
                            const char *b2_name)
 {
-    /* we will stop sending 'proto xxx' in OCC in a future version
-     * (because it's not useful), and to reduce questions when
-     * interoperating, we start not-printing a warning about it today
+    /* We will stop sending 'key-method', 'keydir', 'proto' and 'tls-auth' in
+     * OCC in a future version (because it's not useful).  To reduce questions
+     * when interoperating, we no longer printing a warning about it.
      */
